#!/bin/sh
#
# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2006, 2009. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT
# ---------------------------------------------------------
# -- This batch file creates the Business Space database 
# --
# -- REQUIREMENTS: 
# -- Derby 10.1  must be installed
# -- 
# -- This file for use on linux systems
# -- 
# Usage: 
#      configBusinessSpaceDB.sh   [createDB]
#
# Parameters:
#      createDB    - specify whether or not  to create a new database
#            
# Example:
#      configBusinessSpaceDB.sh  createDB   //create a new database
#      configBusinessSpaceDB.sh             // use an existing database
#
# Note:
#	   Enter user name and password to get database connection first.
#	   Note Database will be created at $DB_DIR_DB_NAME
# 	   Run this script from its folder instead of a different folder.
#
# Return Codes:
#	   0 for success, non zero for failed
#
#------------------------------------------------------------------------------

# Setup WebSphere environment
# Location of java home is set by this

DB_CREATE=$1


################################
#  DB_NAME will be replaced 
################################
DB_NAME=@DB_NAME@
INIT_DIR=`pwd`
CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" = "." ] ; then
   CURRENT_DIR=`pwd`
fi



if [ "$DB_CREATE" = "createDB" ] 
then
    createDB=true
else
    createDB=false
fi   

# Setup WebSphere environment
# this sets the JAVA_HOME

USER_INSTALL_ROOT=`dirname ../../../../../`

if [ ! -f $USER_INSTALL_ROOT/bin/setupCmdLine.sh ];then
	USER_INSTALL_ROOT="$PWD/../../../../../"
fi

if [ -f $USER_INSTALL_ROOT/bin/setupCmdLine.sh ];then
	. "$USER_INSTALL_ROOT/bin/setupCmdLine.sh"
else
	echo "Please enter Profile home directory: "
    read USER_INSTALL_ROOT
	. "$USER_INSTALL_ROOT/bin/setupCmdLine.sh"
fi


DB_DIR=$USER_INSTALL_ROOT/databases
DB_DIR_DB_NAME=$USER_INSTALL_ROOT/databases/$DB_NAME  

cd $CURRENT_DIR

if [ "$createDB" == "true" ] 
then
	#  Create  a new commonDB database and tables
	for i  in `ls | egrep "createSchema_BusinessSpace|createTablespace_BusinessSpace"`
	do
		"$JAVA_HOME/bin/java" -classpath "$WAS_HOME/derby/lib/derby.jar:$WAS_HOME/derby/lib/derbytools.jar:$WAS_HOME/derby/lib/jh.jar" -Ddb2j.system.home=$DB_DIR -Dij.protocol=jdbc:derby: -Dij.database="$DB_DIR_DB_NAME;create=true;" org.apache.derby.tools.ij $i
	done	
	"$JAVA_HOME/bin/java" -classpath "$WAS_HOME/derby/lib/derby.jar:$WAS_HOME/derby/lib/derbytools.jar:$WAS_HOME/derby/lib/jh.jar" -Ddb2j.system.home=$DB_DIR -Dij.protocol=jdbc:derby: -Dij.database="$DB_DIR_DB_NAME;create=true;" org.apache.derby.tools.ij "createTable_BusinessSpace.sql"
else
	# Now use an existing database and create commonDB tables	
	for i  in `ls | egrep "createSchema_BusinessSpace|createTablespace_BusinessSpace"`
	do
		"$JAVA_HOME/bin/java" -classpath "$WAS_HOME/derby/lib/derby.jar:$WAS_HOME/derby/lib/derbytools.jar:$WAS_HOME/derby/lib/jh.jar" -Ddb2j.system.home=$DB_DIR -Dij.protocol=jdbc:derby: -Dij.database=$DB_DIR_DB_NAME org.apache.derby.tools.ij $i
	done
	"$JAVA_HOME/bin/java" -classpath "$WAS_HOME/derby/lib/derby.jar:$WAS_HOME/derby/lib/derbytools.jar:$WAS_HOME/derby/lib/jh.jar" -Ddb2j.system.home=$DB_DIR -Dij.protocol=jdbc:derby: -Dij.database=$DB_DIR_DB_NAME org.apache.derby.tools.ij "createTable_BusinessSpace.sql"
fi

cd $INIT_DIR
